@@ -1,19 +1,9 @@
+#include "text_source.h"
 
 #include <QString>
 #include <QSyntaxHighlighter>
 #include <QTextBrowser>
 
-// A pure-interface class used by InfiniteScrollViewer.
-class TextSource
-{
-public:
-	virtual QString getSourceName()=0;
-	virtual QString getSourceDescrip(bool bShort)=0;
-	virtual int getNumSections()=0;
-	virtual int getNumParagraphs(int section)=0;
-	virtual QString getText(int section, int paragraph)=0;
-};
-
 class SearchResultsHighlighter : public QSyntaxHighlighter
 {
 	Q_OBJECT
@@ -93,6 +83,7 @@ private:
 	bool mNewLineForParagraphs;
 	bool mShowShortTitle;
 
+	bool mHasDoneInitialFill;
 	int mFirstSection;
 	int mFirstParagraph;
 	int mLastSection;
