@@ -137,7 +137,12 @@ InstallTranslationsDialog::InstallTranslationsDialog(QWidget* pParent) :
 	installLayout->insertStretch(1);
 	installLayout->addWidget(installButton);
 	mainLayout->addLayout(installLayout);
-	setLayout(mainLayout);
+	QVBoxLayout* pdbLayout = new QVBoxLayout;
+	pdbLayout->addLayout(mainLayout);
+	QString pdbLabelText = "(PalmBible+ files can be used by "
+							"copying them to the MyDocs folder.)";
+	pdbLayout->addWidget(new QLabel(pdbLabelText));
+	setLayout(pdbLayout);
 
 	connect(mLanguageCombo, SIGNAL(currentIndexChanged(const QString&)),
 			this, SLOT(onLanguageChange(const QString&)));
